Learn R Programming

condensr (version 1.0.0)

publication: Generate publication

Description

Generates a publication object that is linked from staff websites

Usage

publication(title, related_staff, link, citation, date)

Value

An object of class publication with 5 elements:

  • title

  • related_staff

  • link

  • citation

  • date

Arguments

title

Title of the publication.

related_staff

Vector of the ids of the related staff.

link

URL of the publication that will be linked.

citation

Text that will be displayed for this publication.

date

Date of publication. List of publications is sorted on the staff pages.

Examples

Run this code
example_publication <- publication(
    title = "Joe's Blogging Paper",
    related_staff = c("joe-bloggs"),
    link = NA,
    citation = "Bloggs, J., Bloggy, Y. (2019),
         The power of blogging, Australian Journal of Bloggs, 43: 149-155.",
    date = as.Date("2019-01-01")
)

Run the code above in your browser using DataLab